---
jupytext:
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.13
    jupytext_version: 1.14.5
---

```{code-cell}
:tags: [remove-input]

import intake
import ciofs_hindcast_report as chr
import hvplot.pandas  # noqa
import ocean_model_skill_assessor as omsa
import pandas as pd
import cmocean.cm as cmo
from IPython.display import Image, display
```

(page:hfradar-comparison)=
# HF Radar (UAF)

* hfradar

See the full dataset page for more information: {ref}`page:hfradar`

+++

## Map of HF Radar Data Areas



````{div} full-width                
```{figure} map_of_hfradar.png
---
name: 
---
Map of HF Radar areas
```
````




+++

## lower-ci_system-B_2006-2007


+++

### M2 Tidal Ellipses


+++

#### CIOFS


+++



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_M2_ellipses.png
---
name: fig-lower-ci_system-B_2006-2007-ciofs-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
M2 tidal ellipses from surface currents for CIOFS and dataset lower-ci_system-B_2006-2007
```
````


+++

#### NWGOA


+++



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_M2_ellipses.png
---
name: fig-lower-ci_system-B_2006-2007-nwgoa-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
M2 tidal ellipses from surface currents for NWGOA and dataset lower-ci_system-B_2006-2007
```
````


+++

### K1 Tidal Ellipses


+++

#### CIOFS


+++



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_K1_ellipses.png
---
name: fig-lower-ci_system-B_2006-2007-ciofs-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
K1 tidal ellipses from surface currents for CIOFS and dataset lower-ci_system-B_2006-2007
```
````


+++

#### NWGOA


+++



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_K1_ellipses.png
---
name: fig-lower-ci_system-B_2006-2007-nwgoa-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
K1 tidal ellipses from surface currents for NWGOA and dataset lower-ci_system-B_2006-2007
```
````


+++

### Subtidal Mean


+++

#### CIOFS


+++



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_all_east_north_remove-under-50-percent-data_units-to-meters_subtidal_mean.png
---
name: fig-lower-ci_system-B_2006-2007-ciofs-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
Subtidal mean from surface currents for CIOFS and dataset lower-ci_system-B_2006-2007
```
````


+++

#### NWGOA


+++



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_all_east_north_remove-under-50-percent-data_units-to-meters_subtidal_mean.png
---
name: fig-lower-ci_system-B_2006-2007-nwgoa-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
Subtidal mean from surface currents for NWGOA and dataset lower-ci_system-B_2006-2007
```
````


+++

### Hourly


+++

#### CIOFS


+++



````{div} full-width                
```{figure} https://files.axds.co/ciofs/hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_all_east_north_remove-under-50-percent-data_units-to-meters.mp4
---
name: fig-lower-ci_system-B_2006-2007-ciofs-Hourly
class: video controls
width: 1000px
---
Hourly from surface currents for CIOFS and dataset lower-ci_system-B_2006-2007
```
````


+++

#### NWGOA


+++



````{div} full-width                
```{figure} https://files.axds.co/ciofs/hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_all_east_north_remove-under-50-percent-data_units-to-meters.mp4
---
name: fig-lower-ci_system-B_2006-2007-nwgoa-Hourly
class: video controls
width: 1000px
---
Hourly from surface currents for NWGOA and dataset lower-ci_system-B_2006-2007
```
````


+++

### Subtidal, 6-Hourly


+++

#### CIOFS


+++



````{div} full-width                
```{figure} https://files.axds.co/ciofs/hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_all_east_north_remove-under-50-percent-data_units-to-meters_subtidal_resample-6H.mp4
---
name: fig-lower-ci_system-B_2006-2007-ciofs-Subtidal, 6-Hourly
class: video controls
width: 1000px
---
Subtidal, 6-hourly from surface currents for CIOFS and dataset lower-ci_system-B_2006-2007
```
````


+++

#### NWGOA


+++



````{div} full-width                
```{figure} https://files.axds.co/ciofs/hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_all_east_north_remove-under-50-percent-data_units-to-meters_subtidal_resample-6H.mp4
---
name: fig-lower-ci_system-B_2006-2007-nwgoa-Subtidal, 6-Hourly
class: video controls
width: 1000px
---
Subtidal, 6-hourly from surface currents for NWGOA and dataset lower-ci_system-B_2006-2007
```
````


+++

### Tidal Constants


+++


``````{div} full-width 
`````{dropdown} CIOFS
### Major Amplitude



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_M2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_K1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_S2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_N2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_O1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_Q1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_K2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_P1-major.png
---
name: 
---

```
````

### Minor Amplitude



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_M2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_K1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_S2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_N2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_O1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_Q1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_K2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_P1-minor.png
---
name: 
---

```
````

### Phase



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_M2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_K1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_S2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_N2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_O1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_Q1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_K2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_P1-phase.png
---
name: 
---

```
````

### Inclination



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_M2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_K1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_S2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_N2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_O1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_Q1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_K2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_lower-ci_system-B_2006-2007_P1-inclination.png
---
name: 
---

```
````



`````
``````

+++


``````{div} full-width 
`````{dropdown} NWGOA
### Major Amplitude



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_M2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_K1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_S2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_N2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_O1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_Q1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_K2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_P1-major.png
---
name: 
---

```
````

### Minor Amplitude



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_M2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_K1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_S2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_N2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_O1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_Q1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_K2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_P1-minor.png
---
name: 
---

```
````

### Phase



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_M2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_K1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_S2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_N2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_O1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_Q1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_K2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_P1-phase.png
---
name: 
---

```
````

### Inclination



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_M2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_K1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_S2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_N2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_O1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_Q1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_K2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_lower-ci_system-B_2006-2007_P1-inclination.png
---
name: 
---

```
````



`````
``````

+++

## upper-ci_system-A_2002-2003


+++

### M2 Tidal Ellipses


+++

#### CIOFS


+++



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_M2_ellipses.png
---
name: fig-upper-ci_system-A_2002-2003-ciofs-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
M2 tidal ellipses from surface currents for CIOFS and dataset upper-ci_system-A_2002-2003
```
````


+++

#### NWGOA


+++



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_M2_ellipses.png
---
name: fig-upper-ci_system-A_2002-2003-nwgoa-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
M2 tidal ellipses from surface currents for NWGOA and dataset upper-ci_system-A_2002-2003
```
````


+++

### K1 Tidal Ellipses


+++

#### CIOFS


+++



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_K1_ellipses.png
---
name: fig-upper-ci_system-A_2002-2003-ciofs-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
K1 tidal ellipses from surface currents for CIOFS and dataset upper-ci_system-A_2002-2003
```
````


+++

#### NWGOA


+++



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_K1_ellipses.png
---
name: fig-upper-ci_system-A_2002-2003-nwgoa-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
K1 tidal ellipses from surface currents for NWGOA and dataset upper-ci_system-A_2002-2003
```
````


+++

### Subtidal Mean


+++

#### CIOFS


+++



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_all_east_north_remove-under-50-percent-data_units-to-meters_subtidal_mean.png
---
name: fig-upper-ci_system-A_2002-2003-ciofs-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
Subtidal mean from surface currents for CIOFS and dataset upper-ci_system-A_2002-2003
```
````


+++

#### NWGOA


+++



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_all_east_north_remove-under-50-percent-data_units-to-meters_subtidal_mean.png
---
name: fig-upper-ci_system-A_2002-2003-nwgoa-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
Subtidal mean from surface currents for NWGOA and dataset upper-ci_system-A_2002-2003
```
````


+++

### Hourly


+++

#### CIOFS


+++



````{div} full-width                
```{figure} https://files.axds.co/ciofs/hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_all_east_north_remove-under-50-percent-data_units-to-meters.mp4
---
name: fig-upper-ci_system-A_2002-2003-ciofs-Hourly
class: video controls
width: 1000px
---
Hourly from surface currents for CIOFS and dataset upper-ci_system-A_2002-2003
```
````


+++

#### NWGOA


+++



````{div} full-width                
```{figure} https://files.axds.co/ciofs/hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_all_east_north_remove-under-50-percent-data_units-to-meters.mp4
---
name: fig-upper-ci_system-A_2002-2003-nwgoa-Hourly
class: video controls
width: 1000px
---
Hourly from surface currents for NWGOA and dataset upper-ci_system-A_2002-2003
```
````


+++

### Subtidal, 6-Hourly


+++

#### CIOFS


+++



````{div} full-width                
```{figure} https://files.axds.co/ciofs/hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_all_east_north_remove-under-50-percent-data_units-to-meters_subtidal_resample-6H.mp4
---
name: fig-upper-ci_system-A_2002-2003-ciofs-Subtidal, 6-Hourly
class: video controls
width: 1000px
---
Subtidal, 6-hourly from surface currents for CIOFS and dataset upper-ci_system-A_2002-2003
```
````


+++

#### NWGOA


+++



````{div} full-width                
```{figure} https://files.axds.co/ciofs/hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_all_east_north_remove-under-50-percent-data_units-to-meters_subtidal_resample-6H.mp4
---
name: fig-upper-ci_system-A_2002-2003-nwgoa-Subtidal, 6-Hourly
class: video controls
width: 1000px
---
Subtidal, 6-hourly from surface currents for NWGOA and dataset upper-ci_system-A_2002-2003
```
````


+++

### Tidal Constants


+++


``````{div} full-width 
`````{dropdown} CIOFS
### Major Amplitude



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_M2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_K1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_S2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_N2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_O1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_Q1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_K2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_P1-major.png
---
name: 
---

```
````

### Minor Amplitude



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_M2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_K1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_S2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_N2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_O1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_Q1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_K2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_P1-minor.png
---
name: 
---

```
````

### Phase



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_M2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_K1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_S2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_N2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_O1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_Q1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_K2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_P1-phase.png
---
name: 
---

```
````

### Inclination



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_M2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_K1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_S2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_N2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_O1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_Q1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_K2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2002-2003_P1-inclination.png
---
name: 
---

```
````



`````
``````

+++


``````{div} full-width 
`````{dropdown} NWGOA
### Major Amplitude



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_M2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_K1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_S2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_N2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_O1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_Q1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_K2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_P1-major.png
---
name: 
---

```
````

### Minor Amplitude



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_M2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_K1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_S2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_N2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_O1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_Q1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_K2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_P1-minor.png
---
name: 
---

```
````

### Phase



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_M2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_K1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_S2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_N2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_O1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_Q1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_K2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_P1-phase.png
---
name: 
---

```
````

### Inclination



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_M2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_K1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_S2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_N2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_O1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_Q1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_K2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_nwgoa/hfradar_upper-ci_system-A_2002-2003_P1-inclination.png
---
name: 
---

```
````



`````
``````

+++

## upper-ci_system-A_2009


+++

### M2 Tidal Ellipses


+++

#### CIOFS


+++



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_M2_ellipses.png
---
name: fig-upper-ci_system-A_2009-ciofs-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
M2 tidal ellipses from surface currents for CIOFS and dataset upper-ci_system-A_2009
```
````


+++

#### NWGOA


+++


NWGOA: Data time range is 2009-04-19 to 2009-06-07 but model ends 2009-01-01.


+++

### K1 Tidal Ellipses


+++

#### CIOFS


+++



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_K1_ellipses.png
---
name: fig-upper-ci_system-A_2009-ciofs-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
K1 tidal ellipses from surface currents for CIOFS and dataset upper-ci_system-A_2009
```
````


+++

#### NWGOA


+++


NWGOA: Data time range is 2009-04-19 to 2009-06-07 but model ends 2009-01-01.


+++

### Subtidal Mean


+++

#### CIOFS


+++



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_all_east_north_remove-under-50-percent-data_units-to-meters_subtidal_mean.png
---
name: fig-upper-ci_system-A_2009-ciofs-M2 Tidal Ellipses_K1 Tidal Ellipses_Subtidal Mean_Hourly_Subtidal, 6-Hourly
---
Subtidal mean from surface currents for CIOFS and dataset upper-ci_system-A_2009
```
````


+++

#### NWGOA


+++


NWGOA: Data time range is 2009-04-19 to 2009-06-07 but model ends 2009-01-01.


+++

### Hourly


+++

#### CIOFS


+++



````{div} full-width                
```{figure} https://files.axds.co/ciofs/hfradar_ciofs/hfradar_upper-ci_system-A_2009_all_east_north_remove-under-50-percent-data_units-to-meters.mp4
---
name: fig-upper-ci_system-A_2009-ciofs-Hourly
class: video controls
width: 1000px
---
Hourly from surface currents for CIOFS and dataset upper-ci_system-A_2009
```
````


+++

#### NWGOA


+++


NWGOA: Data time range is 2009-04-19 to 2009-06-07 but model ends 2009-01-01.


+++

### Subtidal, 6-Hourly


+++

#### CIOFS


+++



````{div} full-width                
```{figure} https://files.axds.co/ciofs/hfradar_ciofs/hfradar_upper-ci_system-A_2009_all_east_north_remove-under-50-percent-data_units-to-meters_subtidal_resample-6H.mp4
---
name: fig-upper-ci_system-A_2009-ciofs-Subtidal, 6-Hourly
class: video controls
width: 1000px
---
Subtidal, 6-hourly from surface currents for CIOFS and dataset upper-ci_system-A_2009
```
````


+++

#### NWGOA


+++


NWGOA: Data time range is 2009-04-19 to 2009-06-07 but model ends 2009-01-01.


+++

### Tidal Constants


+++


``````{div} full-width 
`````{dropdown} CIOFS
### Major Amplitude



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_M2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_K1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_S2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_N2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_O1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_Q1-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_K2-major.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_P1-major.png
---
name: 
---

```
````

### Minor Amplitude



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_M2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_K1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_S2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_N2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_O1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_Q1-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_K2-minor.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_P1-minor.png
---
name: 
---

```
````

### Phase



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_M2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_K1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_S2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_N2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_O1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_Q1-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_K2-phase.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_P1-phase.png
---
name: 
---

```
````

### Inclination



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_M2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_K1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_S2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_N2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_O1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_Q1-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_K2-inclination.png
---
name: 
---

```
````



````{div} full-width                
```{figure} hfradar_ciofs/hfradar_upper-ci_system-A_2009_P1-inclination.png
---
name: 
---

```
````



`````
``````

+++


NWGOA: Data time range is 2009-04-19 to 2009-06-07 but model ends 2009-01-01.
